;; Generated package description from undo-tree.el  -*- no-byte-compile: t -*-
(define-package "undo-tree" "0.7.5.0.20201128.184009" "Treat undo history as a tree" 'nil :keywords '("convenience" "files" "undo" "redo" "history" "tree") :authors '(("Toby Cubitt" . "toby-undo-tree@dr-qubit.org")) :maintainer '("Toby Cubitt" . "toby-undo-tree@dr-qubit.org") :url "http://www.dr-qubit.org/emacs.php")
